==> crm-commom-vo-1.1.7.1.release.jar: com/biz/crm/nebular/mdm/dict/resp/DictDataVo.java <==
package com.biz.crm.nebular.mdm.dict.resp;

import java.io.Serializable;
import java.util.List;

public class DictDataVo implements Serializable {

    private static final long serialVersionUID = 1598781191569129220L;
    private String dictCode;
    private String dictValue;
    private String dictDesc;
    private String dictTypeCode;
    private String parentDictCode;
    private String dictSort;
    private String ext1;
    private String ext2;
    private String ext3;
    private String ext4;
    private String ext5;
    private String ext6;
    private String ext7;
    private String ext8;
    private String ext9;
    private String ext10;
    private List<DictDataVo> children;

    public String getDictCode() {
        return dictCode;
    }

    public void setDictCode(String dictCode) {
        this.dictCode = dictCode;
    }

    public String getDictValue() {
        return dictValue;
    }

    public void setDictValue(String dictValue) {
        this.dictValue = dictValue;
    }

    public String getDictDesc() {
        return dictDesc;
    }

    public void setDictDesc(String dictDesc) {
        this.dictDesc = dictDesc;
    }

    public String getDictTypeCode() {
        return dictTypeCode;
    }

    public void setDictTypeCode(String dictTypeCode) {
        this.dictTypeCode = dictTypeCode;
    }

    public String getParentDictCode() {
        return parentDictCode;
    }

    public void setParentDictCode(String parentDictCode) {
        this.parentDictCode = parentDictCode;
    }

    public String getDictSort() {
        return dictSort;
    }

    public void setDictSort(String dictSort) {
        this.dictSort = dictSort;
    }

    public String getExt1() {
        return ext1;
    }

    public void setExt1(String ext1) {
        this.ext1 = ext1;
    }

    public String getExt2() {
        return ext2;
    }

    public void setExt2(String ext2) {
        this.ext2 = ext2;
    }

    public String getExt3() {
        return ext3;
    }

    public void setExt3(String ext3) {
        this.ext3 = ext3;
    }

    public String getExt4() {
        return ext4;
    }

    public void setExt4(String ext4) {
        this.ext4 = ext4;
    }

    public String getExt5() {
        return ext5;
    }

    public void setExt5(String ext5) {
        this.ext5 = ext5;
    }

    public String getExt6() {
        return ext6;
    }

    public void setExt6(String ext6) {
        this.ext6 = ext6;
    }

    public String getExt7() {
        return ext7;
    }

    public void setExt7(String ext7) {
        this.ext7 = ext7;
    }

    public String getExt8() {
        return ext8;
    }

    public void setExt8(String ext8) {
        this.ext8 = ext8;
    }

    public String getExt9() {
        return ext9;
    }

    public void setExt9(String ext9) {
        this.ext9 = ext9;
    }

    public String getExt10() {
        return ext10;
    }

    public void setExt10(String ext10) {
        this.ext10 = ext10;
    }

    public List<DictDataVo> getChildren() {
        return children;
    }

    public void setChildren(List<DictDataVo> children) {
        this.children = children;
    }
}

==> crm-commom-vo-1.1.7.1.2.release.jar: com/biz/crm/nebular/mdm/dict/resp/DictDataVo.java <==
package com.biz.crm.nebular.mdm.dict.resp;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 数据字典值VO
 */
public class DictDataVo {

    /***字典编码*/
    private String dictCode;
    /***字典值*/
    private String dictValue;
    /***字典值描述*/
    private String dictDesc;
    /***字典类型编码*/
    private String dictTypeCode;
    /***字典编码上级编码*/
    private String parentDictCode;
    /***顺序*/
    private String dictSort;
    /***扩展字段MAP*/
    private Map<String, String> extendMap = new HashMap<>(16);
    /***下级，树形结构接口才有值*/
    private List<DictDataVo> children;

    public String getDictCode() {
        return dictCode;
    }

    public void setDictCode(String dictCode) {
        this.dictCode = dictCode;
    }

    public String getDictValue() {
        return dictValue;
    }

    public void setDictValue(String dictValue) {
        this.dictValue = dictValue;
    }

    public String getDictDesc() {
        return dictDesc;
    }

    public void setDictDesc(String dictDesc) {
        this.dictDesc = dictDesc;
    }

    public String getDictTypeCode() {
        return dictTypeCode;
    }

    public void setDictTypeCode(String dictTypeCode) {
        this.dictTypeCode = dictTypeCode;
    }

    public String getParentDictCode() {
        return parentDictCode;
    }

    public void setParentDictCode(String parentDictCode) {
        this.parentDictCode = parentDictCode;
    }

    public String getDictSort() {
        return dictSort;
    }

    public void setDictSort(String dictSort) {
        this.dictSort = dictSort;
    }

    public Map<String, String> getExtendMap() {
        return extendMap;
    }

    public void setExtendMap(Map<String, String> extendMap) {
        this.extendMap = extendMap;
    }

    public List<DictDataVo> getChildren() {
        return children;
    }

    public void setChildren(List<DictDataVo> children) {
        this.children = children;
    }
}
